// Remove all references to SharedGroup, SharedUser, SharedNote, and SharedPrintHistory. Use only local types for Group, User, Note, and PrintHistory.

export interface TaskWithSteps {
  id: number;
  name: string;
  group_id: number;
  print_count: number;
  last_printed_at?: Date | string | null;
  created_at?: Date | string | null;
  updated_at?: Date | string | null;
  steps: StepWithNotes[];
  notes: NoteWithUser[];
}

export interface StepWithNotes {
  id: number;
  name: string;
  instructions: string;
  task_id: number;
  order: number;
  print_count: number;
  last_printed_at?: Date | string | null;
  created_at?: Date | string | null;
  updated_at?: Date | string | null;
  notes: NoteWithUser[];
}

export type Task = {
  id: number;
  name: string;
  group_id: number;
  print_count: number;
  last_printed_at?: Date | string | null;
  created_at?: Date | string | null;
  updated_at?: Date | string | null;
};

export type Step = {
  id: number;
  name: string;
  instructions: string;
  task_id: number;
  order: number;
  print_count: number;
  last_printed_at?: Date | string | null;
  created_at?: Date | string | null;
  updated_at?: Date | string | null;
};

// Define User, Note, and PrintHistory locally if needed

export interface User {
  id: number;
  name: string;
  created_at?: Date | string | null;
  updated_at?: Date | string | null;
}

export interface Note {
  id: number;
  content: string;
  step_id?: number;
  task_id?: number;
  user_id?: number;
  created_at?: Date | string | null;
  updated_at?: Date | string | null;
}

export interface NoteWithUser extends Note {
  user?: User;
}

export interface PrintHistory {
  id: number;
  user_id: number;
  task_id?: number;
  step_id?: number;
  printed_at: Date | string;
  created_at?: Date | string | null;
  updated_at?: Date | string | null;
}

export interface PrintHistoryWithDetails extends PrintHistory {
  user?: User;
  task?: TaskWithSteps;
  step?: StepWithNotes;
}

export interface Group {
  id: number;
  name: string;
  parent_id?: number;
  created_at?: Date | string | null;
  updated_at?: Date | string | null;
}

export interface GroupWithTasks extends Group {
  tasks: TaskWithSteps[];
}

// All types are now defined locally above. Remove all re-exports and duplicate type definitions at the bottom of the file.